pub struct CalendarDuration { /* private fields */ }
TODO Represent fraction of week with opt f32 see https://github.com/xwde/timext/issues/6


let d0 = Date::from_calendar_date(2023, Month::January, 31).unwrap();
let d1 = Date::from_calendar_date(2023, Month::February, 28).unwrap();
assert_eq!(d0 + 1.months(), d1);

let d0 = Date::from_calendar_date(2024, Month::February, 29).unwrap();
let d1 = Date::from_calendar_date(2025, Month::February, 28).unwrap();///
assert_eq!(d0 + 1.years(), d1);

Implementations

source

impl CalendarDuration

source

pub const fn new(years: i32, months: i32) -> Self

Creates a new CalendarDuration with provided years and months.

let d0 = CalendarDuration::new(2, 24);
assert_eq!(d0.whole_years(), 4);
assert_eq!(d0.whole_months(), 48);
source

pub const fn years(years: i32) -> Self

Creates a new CalendarDuration with provided years.

let d0 = CalendarDuration::years(2);
assert_eq!(d0.whole_years(), 2);
assert_eq!(d0.whole_months(), 24);
source

pub const fn months(months: i32) -> Self

Creates a new CalendarDuration with provided months.

let d0 = CalendarDuration::months(24);
assert_eq!(d0.whole_years(), 2);
assert_eq!(d0.whole_months(), 24);
source

pub const MIN: Self = _

source

pub const MAX: Self = _

source

impl CalendarDuration

source

pub const fn whole_years(self) -> i32

Returns the number of whole years in the CalendarDuration.

assert_eq!(1.years().whole_years(), 1);
assert_eq!((-1).years().whole_years(), -1);
assert_eq!(6.months().whole_years(), 0);
assert_eq!((-6).months().whole_years(), 0);
source

pub const fn whole_months(self) -> i32

Returns the number of whole months in the CalendarDuration.

assert_eq!(1.months().whole_months(), 1);
assert_eq!((-1).months().whole_months(), -1);
assert_eq!(6.months().whole_years(), 0);
assert_eq!((-6).months().whole_years(), 0);
source

pub const fn subyear_months(self) -> i32

Returns the number of months past the number of whole years.

assert_eq!(13.months().subyear_months(), 1);
assert_eq!((-13).months().subyear_months(), -1);
source

pub const fn is_zero(self) -> bool

Checks if a duration is negative.

assert!(0.months().is_zero());
assert!(!1.months().is_zero());
source

pub const fn is_positive(self) -> bool

Checks if a CalendarDuration is positive.

assert!(1.months().is_positive());
assert!(!0.months().is_positive());
assert!(!(-1).months().is_positive());
source

pub const fn is_negative(self) -> bool

Checks if a CalendarDuration is negative.

assert!((-1).months().is_negative());
assert!(!0.months().is_negative());
assert!(!1.months().is_negative());
source

impl CalendarDuration

source

pub const fn abs(self) -> Self

Returns the absolute value of the duration.

assert_eq!(1.months().abs(), 1.months());
assert_eq!(0.months().abs(), 0.months());
assert_eq!((-1).months().abs(), 1.months());
source

impl CalendarDuration

source

pub fn checked_date_add(date: Date, duration: Self) -> Option<Date>

Returns the sum of provided Date and CalendarDuration.

let d0 = Date::from_calendar_date(2018, September, 1).unwrap();
let d1 = Date::from_calendar_date(2018, October, 1).unwrap();
let rs = CalendarDuration::checked_date_add(d0, 1.months());
assert_eq!(rs.unwrap(), d1);
source

pub fn checked_date_sub(date: Date, duration: Self) -> Option<Date>

Returns the difference of provided Date and CalendarDuration.

let d0 = Date::from_calendar_date(2018, September, 1).unwrap();
let d1 = Date::from_calendar_date(2018, August, 1).unwrap();
let rs = CalendarDuration::checked_date_sub(d0, 1.months());
assert_eq!(rs.unwrap(), d1);
source

impl CalendarDuration

source

pub fn checked_add(self, rhs: Self) -> Option<Self>

Computes self + rhs, returning None if an overflow occurred.

assert_eq!(5.months().checked_add(5.months()), Some(10.months()));
assert_eq!(CalendarDuration::MAX.checked_add(1.months()), None);
assert_eq!((-5).months().checked_add(5.months()), Some(0.months()));
source

pub fn checked_sub(self, rhs: Self) -> Option<Self>

Computes self - rhs, returning None if an overflow occurred.

assert_eq!(5.months().checked_sub(5.months()), Some(0.months()));
assert_eq!(CalendarDuration::MIN.checked_sub(1.months()), None);
assert_eq!(5.months().checked_sub(5.months()), Some(0.months()));
source

pub fn checked_mul(self, rhs: i32) -> Option<Self>

Computes self * rhs, returning None if an overflow occurred.

assert_eq!(5.months().checked_mul(2), Some(10.months()));
assert_eq!(5.months().checked_mul(-2), Some((-10).months()));
assert_eq!(5.months().checked_mul(0), Some(0.months()));
assert_eq!(CalendarDuration::MAX.checked_mul(2), None);
assert_eq!(CalendarDuration::MIN.checked_mul(2), None);
source

pub fn checked_div(self, rhs: i32) -> Option<Self>

Computes self / rhs, returning None if rhs == 0 or if the result would overflow.

assert_eq!(10.months().checked_div(2), Some(5.months()));
assert_eq!(10.months().checked_div(-2), Some((-5).months()));
assert_eq!(1.months().checked_div(0), None);
source

pub fn checked_neg(self) -> Option<Self>

Computes -self, returning None if an overflow occurred.

assert_eq!(10.months().checked_neg(), Some((-10).months()));
assert_eq!(CalendarDuration::MIN.checked_neg(), None);